==> ht-js-client-0.0.14.tgz: package/src/ht-client.ts <==
export * from "./request";
export * from "./api/actions";
export * from "./api/users";
export * from "./api/base";
// export * from "./client";
export * from "./config";
export * from "./interfaces";
export * from "./entities/actions/actions-client"
export * from "./entities/actions/actions-list-client"
export * from "./entities/actions/actions-get-client"
export * from "./entities/users/users-client"
export * from "./entities/users/users-index-client"
export * from "./entities/users/user-placeline-client"
export * from "./entities/users/users-analytics-client"
export * from "./client"
export * from "./base/base-client";
export * from "./base/data-observer";
export * from "./base/list-client";
export * from "./base/item-client";

import 'rxjs/add/operator/do';
import 'rxjs/add/operator/filter';
import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/startWith';
import 'rxjs/add/operator/share';
import 'rxjs/add/operator/shareReplay';
import 'rxjs/add/operator/distinctUntilChanged';
import 'rxjs/add/operator/publishReplay';
import 'rxjs/add/operator/take';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/merge';
import 'rxjs/add/operator/pluck';
import 'rxjs/add/operator/switchMap';
import 'rxjs/add/operator/exhaustMap';
import 'rxjs/add/operator/skip';
import 'rxjs/add/operator/takeUntil';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/expand';
import 'rxjs/add/operator/isEmpty';
import 'rxjs/add/operator/scan';
import 'rxjs/add/operator/withLatestFrom';
import "rxjs/add/operator/mergeMap";


import 'rxjs/add/observable/merge';
import 'rxjs/add/observable/empty';
import 'rxjs/add/observable/interval';
import 'rxjs/add/observable/timer';
import 'rxjs/add/observable/combineLatest';
import 'rxjs/add/observable/of';
import 'rxjs/add/observable/zip';

==> ht-js-client-0.0.20.tgz: package/src/ht-client.ts <==
export * from "./request";
export * from "./api/actions";
export * from "./api/users";
export * from "./api/base";
// export * from "./client";
export * from "./config";
export * from "./interfaces";
export * from "./entities/actions/actions-client"
export * from "./entities/actions/actions-list-client"
export * from "./entities/actions/actions-get-client"

//users
export * from "./entities/users/users-index-interfaces";
export * from "./entities/users/users-analytics-interfaces";
export * from "./entities/users/users-placeline-interfaces";
export * from "./entities/users/users-client"
export * from "./entities/users/users-index-client"
export * from "./entities/users/users-placeline-client"
export * from "./entities/users/users-analytics-client"

export * from "./client"
export * from "./base/data-observer";

//groups
export * from "./entities/groups/groups-item-interface";
export * from "./entities/groups/groups-list-interface";
export * from "./entities/groups/groups-client";
export * from "./entities/groups/groups-list";
export * from "./entities/groups/groups-item-client";

import 'rxjs/add/operator/do';
import 'rxjs/add/operator/filter';
import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/startWith';
import 'rxjs/add/operator/share';
import 'rxjs/add/operator/shareReplay';
import 'rxjs/add/operator/distinctUntilChanged';
import 'rxjs/add/operator/publishReplay';
import 'rxjs/add/operator/take';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/merge';
import 'rxjs/add/operator/pluck';
import 'rxjs/add/operator/switchMap';
import 'rxjs/add/operator/exhaustMap';
import 'rxjs/add/operator/skip';
import 'rxjs/add/operator/takeUntil';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/expand';
import 'rxjs/add/operator/isEmpty';
import 'rxjs/add/operator/scan';
import 'rxjs/add/operator/withLatestFrom';
import "rxjs/add/operator/mergeMap";
import "rxjs/add/operator/let";


import 'rxjs/add/observable/merge';
import 'rxjs/add/observable/empty';
import 'rxjs/add/observable/interval';
import 'rxjs/add/observable/timer';
import 'rxjs/add/observable/combineLatest';
import 'rxjs/add/observable/of';
import 'rxjs/add/observable/zip';
